#!/usr/bin/env python
import sys

import numpy as np

from classes.mesh import Mesh
from operations.base import Face
from operations.operations import Revolve
from util import geometry as g

import parameters as p

# extension in the direction of flow (x-axis)
x_start = np.array([-3*p.r_outer, 0, 0])
x_end = np.array([5*p.r_outer, 0, 0])

# domain is a 120 degree section of a cylinder,
# revolved around y-axis
face = Face([
    x_start,
    x_end,
    p.outside_vertex + x_end,
    p.outside_vertex + x_start
]).rotate([1, 0, 0], -p.a/2)

domain = Revolve(face, p.a, [1, 0, 0], [0, 0, 0])
domain.set_cell_count(0, 10)
domain.set_cell_count(1, 30)
domain.set_cell_count(2, 30)

domain.set_patch('bottom', 'cyclicLeft')
domain.set_patch('top', 'cyclicRight')
domain.set_patch('back', 'top')
domain.set_patch('left', 'inlet')
domain.set_patch('right', 'outlet')

mesh = Mesh()
mesh.add_operation(domain)

mesh.write('util/blockMeshDict.template', 'blockMeshDict.donut')
print("blockMeshDict.donut created")